"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.analyzeCodebase = void 0;
const chalk_1 = __importDefault(require("chalk"));
const file_1 = require("../analyze/file");
const file_2 = require("../utils/file");
const output_1 = require("../utils/output");
const analyzeCodebase = async (options) => {
    const start = Date.now();
    const fileNameCases = {};
    const output = {
        Physical: 0,
        Source: 0,
        Comment: 0,
        SingleLineComment: 0,
        BlockComment: 0,
        Mixed: 0,
        EmptyBlockComment: 0,
        Empty: 0,
        ToDo: 0,
    };
    console.log(chalk_1.default.bold(`\n\nAnalyzing codebase in ${chalk_1.default.cyan(options.directory)} ${(options === null || options === void 0 ? void 0 : options.framework) ? `framework: ${chalk_1.default.cyan(options.framework)}` : ""}\n`));
    let fileCount = 0;
    await (0, file_2.traverseDirectory)({
        extensions: options.extensions,
        directory: options.directory,
        exclude: options.exclude,
        checkFileNames: options.checkFileNames,
        onFile: (filePath) => {
            fileCount++;
            const { fileNameCase } = (0, file_1.analyzeFile)(filePath, output);
            if (fileNameCases[fileNameCase] !== undefined)
                fileNameCases[fileNameCase] += 1;
            else
                fileNameCases[fileNameCase] = 0;
        },
    });
    await (0, output_1.logOutput)({
        fileCount,
        fileNameCases,
        options,
        output,
    });
    const totalSecond = ((Date.now() - start) / 1000).toFixed(2);
    console.log(chalk_1.default.bold(`Time taken: ${chalk_1.default.yellow(totalSecond)}s\n`));
};
exports.analyzeCodebase = analyzeCodebase;
