"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeAnalyzeResult = exports.makeMigrationFromLastFileSystem = exports.readAnalyzeResult = exports.checkFileExist = exports.traverseDirectory = void 0;
const fs = __importStar(require("fs/promises"));
const path = __importStar(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const blackList = [
    "node_modules",
    "dist",
    "build",
    "coverage",
    "public",
    "test",
    "tests",
    "mocks",
];
const traverseDirectory = async ({ directory, onFile, onDirectory, exclude, extensions, checkFileNames = true, skipHidden = true, }) => {
    const files = await fs.readdir(directory, { withFileTypes: true });
    const tasks = files.map(async (file) => {
        var _a;
        const filePath = path.join(directory, file.name);
        if (skipHidden && file.name.startsWith("."))
            return;
        if (file.isDirectory()) {
            if (blackList.includes(file.name) || ((_a = exclude === null || exclude === void 0 ? void 0 : exclude.includes) === null || _a === void 0 ? void 0 : _a.call(exclude, file.name)))
                return;
            onDirectory === null || onDirectory === void 0 ? void 0 : onDirectory(filePath);
            await (0, exports.traverseDirectory)({
                directory: filePath,
                onFile,
                exclude,
                extensions,
                onDirectory,
                checkFileNames,
            });
        }
        else if (checkFileNames) {
            const ext = path.extname(file.name);
            if (extensions === null || extensions === void 0 ? void 0 : extensions.length) {
                if (extensions.includes(ext))
                    await onFile(filePath);
            }
            else
                await onFile(filePath);
        }
    });
    await Promise.all(tasks);
};
exports.traverseDirectory = traverseDirectory;
const checkFileExist = async (filePath) => {
    try {
        await fs.stat(filePath);
        return true;
    }
    catch (_a) {
        return false;
    }
};
exports.checkFileExist = checkFileExist;
const readAnalyzeResult = async (directory) => {
    const filePath = `${directory}/.analyze-codebase/data.json`;
    if (await (0, exports.checkFileExist)(filePath)) {
        return JSON.parse(await fs.readFile(filePath, "utf-8"));
    }
};
exports.readAnalyzeResult = readAnalyzeResult;
const makeMigrationFromLastFileSystem = async (directory) => {
    const data = await (0, exports.readAnalyzeResult)(directory);
    if (data)
        return;
    console.log(chalk_1.default.yellow("Migrating data from the last file system to the new file system...\n"));
    let newAnalyzeOutput;
    const oldAnalyzes = [];
    await (0, exports.traverseDirectory)({
        directory,
        checkFileNames: true,
        extensions: [".json"],
        onFile: async (filePath) => {
            try {
                const fileContent = JSON.parse(await fs.readFile(filePath, "utf-8"));
                oldAnalyzes.push(fileContent);
            }
            catch (error) {
                console.error(chalk_1.default.red(`Error reading the file: ${filePath}.`));
            }
        },
    });
    if (oldAnalyzes.length) {
        newAnalyzeOutput = {
            totalAnalyzeCount: oldAnalyzes.length,
            firstAnalyzeDate: oldAnalyzes[0].date,
            lastAnalyzeDate: oldAnalyzes[oldAnalyzes.length - 1].date,
            results: oldAnalyzes,
        };
        await fs.writeFile(`${directory}/data.json`, JSON.stringify(newAnalyzeOutput, null, 2));
    }
};
exports.makeMigrationFromLastFileSystem = makeMigrationFromLastFileSystem;
const writeAnalyzeResult = async (directory, result) => {
    await (0, exports.makeMigrationFromLastFileSystem)(`${directory}/.analyze-codebase/`);
    const filePath = `${directory}/.analyze-codebase/data.json`;
    let data;
    const existData = await (0, exports.readAnalyzeResult)(directory);
    if (existData) {
        data = existData;
        data.totalAnalyzeCount += 1;
        data.lastAnalyzeDate = new Date().toISOString();
    }
    else {
        // Create the directory if it doesn't exist
        await fs.mkdir(`${directory}/.analyze-codebase`, { recursive: true });
        data = {
            totalAnalyzeCount: 1,
            firstAnalyzeDate: new Date().toISOString(),
            lastAnalyzeDate: new Date().toISOString(),
            results: [],
        };
    }
    if (data.results.length) {
        const lastResult = data.results[data.results.length - 1];
        if (lastResult.fileCount === result.fileCount &&
            JSON.stringify(lastResult.fileNameCases) ===
                JSON.stringify(result.fileNameCases) &&
            JSON.stringify(lastResult.output) === JSON.stringify(result.output)) {
            result.sameAsBefore = (lastResult.sameAsBefore || 0) + 1;
            console.log(chalk_1.default.red(`The result is the same as the last analyze. Same as before count: ${result.sameAsBefore}\n`));
        }
    }
    data.results.push(result);
    await fs.writeFile(filePath, JSON.stringify(data, null, 2));
    return filePath;
};
exports.writeAnalyzeResult = writeAnalyzeResult;
