"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logOutput = void 0;
const cli_table3_1 = __importDefault(require("cli-table3"));
const chalk_1 = __importDefault(require("chalk"));
const file_1 = require("./file");
const logOutput = async ({ fileCount, output, fileNameCases, options, }) => {
    const resultObject = {
        date: new Date().toISOString(),
        fileCount,
        fileNameCases,
        options,
        output,
    };
    // Log the JSON output to the console
    console.log(chalk_1.default.bold("------------- Result -------------\n"));
    if (fileCount === 0) {
        console.log(chalk_1.default.red(`No files found in ${chalk_1.default.cyan(options.directory)} with extensions ${chalk_1.default.cyan(options.extensions)}\n`));
    }
    else {
        if (options.checkFileNames) {
            console.log(chalk_1.default.bold("File Name Summary:\n"));
            const fileNameTable = new cli_table3_1.default({
                head: [
                    chalk_1.default.bold("File Name Case"),
                    chalk_1.default.bold("Count"),
                    chalk_1.default.bold("Percentage"),
                ],
                colWidths: [30, 10, 15],
            });
            Object.entries(fileNameCases).forEach(([key, value]) => {
                const percentage = ((value / fileCount) * 100).toFixed(2);
                fileNameTable.push([key, value.toString(), `${percentage}%`]);
            });
            console.log(fileNameTable.toString());
            console.log("\n");
        }
        if (options.checkFileContent) {
            console.log(chalk_1.default.bold("Content Type Summary:\n"));
            const contentTypeTable = new cli_table3_1.default({
                head: [
                    chalk_1.default.bold("Content Type"),
                    chalk_1.default.bold("Count"),
                    chalk_1.default.bold("Percentage"),
                ],
                colWidths: [30, 10, 15],
            });
            Object.entries(output).forEach(([key, value]) => {
                const percentage = ((value / output.Physical) * 100).toFixed(2);
                contentTypeTable.push([key, value.toString(), `${percentage}%`]);
            });
            console.log(contentTypeTable.toString());
        }
    }
    // Write the JSON output to a file (optional)
    if (options.writeJsonOutput) {
        const writePath = await (0, file_1.writeAnalyzeResult)(options.directory, resultObject);
        console.log(chalk_1.default.bold(`\nJSON output written to: ${chalk_1.default.cyan(writePath)}\n`));
    }
    console.log(chalk_1.default.bold("\n----------------------------"));
    console.log(chalk_1.default.bold(`\nNumber of files read: ${chalk_1.default.yellow(fileCount)}\n`));
};
exports.logOutput = logOutput;
